%define major	0
%define libname	%mklibname metis %{major}
%define devname %mklibname metis -d

Name:		metis
Version:	5.1.0
Release:	%mkrel 7
Summary:	Serial Graph Partitioning and Fill-reducing Matrix Ordering
License:	ASL 2.0 and BSD and LGPLv2+
Group:		Sciences/Other
URL:		http://glaros.dtc.umn.edu/gkhome/views/%{name}
Source0:	http://glaros.dtc.umn.edu/gkhome/fetch/sw/%{name}/%{name}-%{version}.tar.gz

## This patch sets up libmetis soname of libmetis
Patch0:		%{name}-libmetis.patch

## This patch sets up shared GKlib library
Patch1:		%{name}-shared-GKlib.patch

## Specify the width (32 or 64 bits) of the elementary data type
## used in METIS. This is controled by the IDXTYPEWIDTH
## constant.
## For now, on a 32 bit architecture you can only specify a width of 32,
## whereas for a 64 bit architecture you can specify a width of either
## 32 or 64 bits.
Patch2:		%{name}-width-datatype.patch

## This patch sets up GKREGEX, GKRAND, libsuffix options to the Makefiles
Patch4:		%{name}-GKREGEX-GKRAND-LIBSUFFIX-fix.patch

BuildRequires:	cmake >= 2.8
BuildRequires:	openmpi-devel
BuildRequires:	pkgconfig(libpcreposix)
BuildRequires:	help2man
BuildRequires:	libgomp-devel

%description
METIS is a set of serial programs for partitioning graphs,
partitioning finite element meshes, and producing fill reducing
orderings for sparse matrices.

The algorithms implemented in METIS are based on the multilevel
recursive-bisection, multilevel k-way, and multi-constraint
partitioning schemes developed in our lab.

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries
Conflicts:	%{name} < 5.1.0-1

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package -n %{devname}
Summary:	The Metis headers and development-related files
Group:		Sciences/Other
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Obsoletes:	%{name}-devel < 5.1.0-1

%description -n %{devname}
Header and library files of Metis.

%prep
%setup -q
%patch0 -p0
%patch1 -p0
%patch4 -p0

%ifarch x86_64
%patch2 -p0
%endif

%build
# Build metis
%cmake \
	-DCMAKE_C_COMPILER=%{_bindir}/gcc \
	-DCMAKE_CXX_COMPILER=%{_bindir}/g++ \
	-DGKLIB_PATH=./GKlib  \
	-DSHARED=1 \
	-DOPENMP=%{_includedir}/openmpi \
	-DPCRE=%{_includedir} \
	-DCMAKE_CXX_FLAGS="%{optflags} -fopenmp -pthread" \
	-DCMAKE_C_FLAGS="%{optflags} -fopenmp -pthread -lpcreposix" \
	-DCMAKE_VERBOSE_MAKEFILE=1 \
	-DCMAKE_INSTALL_PREFIX=%{_prefix}
%cmake_build

%check
cp -p %{buildroot}%{_bindir}/* graphs
pushd graphs
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./ndmetis mdual.graph
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./mpmetis metis.mesh 2
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./gpmetis test.mgraph 4
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./gpmetis copter2.graph 4
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./graphchk 4elt.graph
popd

%install
%cmake_install

## Generate manpages from binaries
LD_PRELOAD=%{buildroot}%{_libdir}/lib%{name}.so.%{major} \
help2man --version-string="%{version}" -n "Partitions a graph into a specified number of parts." \
 -N --output="gpmetis.1" --no-discard-stderr --help-option="-help" %{buildroot}%{_bindir}/gpmetis

LD_PRELOAD=%{buildroot}%{_libdir}/lib%{name}.so.%{major} \
help2man --version-string="%{version}" \
 -n "Computes a fill-reducing ordering of the vertices of the graph using multilevel nested dissection." \
 -N --output="ndmetis.1" --no-discard-stderr --help-option="-help" %{buildroot}%{_bindir}/ndmetis

LD_PRELOAD=%{buildroot}%{_libdir}/lib%{name}.so.%{major} \
help2man --version-string="%{version}" -n "Partitions a mesh into a specified number of parts." \
 -N --output="mpmetis.1" --no-discard-stderr --help-option="-help" %{buildroot}%{_bindir}/mpmetis

LD_PRELOAD=%{buildroot}%{_libdir}/lib%{name}.so.%{major} \
help2man --version-string="%{version}" -n "Converts a mesh into a graph that is compatible with METIS." \
 -N --output="m2gmetis.1" --no-discard-stderr -h "-help" %{buildroot}%{_bindir}/m2gmetis

mkdir -p %{buildroot}%{_mandir}/man1
mv *.1 %{buildroot}%{_mandir}/man1

%files
%doc LICENSE.txt Changelog manual/manual.pdf
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}

%files -n %{devname}
%doc Changelog
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so


%changelog
* Fri Feb 14 2020 umeabot <umeabot> 5.1.0-7.mga8
+ Revision: 1516905
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 5.1.0-6.mga7
+ Revision: 1299526
- Mageia 7 Mass Rebuild

* Mon Feb 08 2016 umeabot <umeabot> 5.1.0-5.mga6
+ Revision: 943917
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 5.1.0-4.mga5
+ Revision: 746346
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 5.1.0-3.mga5
+ Revision: 727243
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 5.1.0-2.mga5
+ Revision: 682371
- Mageia 5 Mass Rebuild

* Sat Jun 28 2014 wally <wally> 5.1.0-1.mga5
+ Revision: 640881
- fix libification

* Tue Nov 26 2013 philippem <philippem> 5.1.0-0.mga4
+ Revision: 553614
- change group
- fix linking issues and buildrequires
- imported package metis

